pub fn version() -> PylonResult<PylonVersion>Expand description
Returns the version of the loaded Pylon runtime.
Initializes the runtime if it has not been initialized yet.
pub fn version() -> PylonResult<PylonVersion>Returns the version of the loaded Pylon runtime.
Initializes the runtime if it has not been initialized yet.